.. _todo:

TODO
=====

[ ] RFC7844 5. Implementers SHOULD provide a way for clients to control when the
anonymity profiles are used and when standard behavior is preferred.

[ ] RFC2131 2.2 the allocating
server SHOULD probe the reused address before allocating the address,
e.g., with an ICMP echo request, and the client SHOULD probe the
newly received address, e.g., with ARP.

[ ] create tests

[ ] create documentation

[ ] calculate retransmission times for DISCOVER

[ ] listen in several interfaces

[ ] create systemd service

[ ] create init.d daemon

[ ] include MAC anonymization module
